==> wallaroo-2024.4.3.tar.gz: wallaroo-2024.4.3/wallaroo/wallaroo_ml_ops_api_client/models/old_publish.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import (
    define as _attrs_define,
    field as _attrs_field,
)

T = TypeVar("T", bound="OldPublish")


@_attrs_define
class OldPublish:
    """
    Attributes:
        id (int):
        pipeline_name (str):
        pipeline_version_id (int):
    """

    id: int
    pipeline_name: str
    pipeline_version_id: int
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id

        pipeline_name = self.pipeline_name

        pipeline_version_id = self.pipeline_version_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "pipeline_name": pipeline_name,
                "pipeline_version_id": pipeline_version_id,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        pipeline_name = d.pop("pipeline_name")

        pipeline_version_id = d.pop("pipeline_version_id")

        old_publish = cls(
            id=id,
            pipeline_name=pipeline_name,
            pipeline_version_id=pipeline_version_id,
        )

        old_publish.additional_properties = d
        return old_publish

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> wallaroo-2025.1.0.tar.gz: wallaroo-2025.1.0/wallaroo/wallaroo_ml_ops_api_client/models/old_publish.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import (
    define as _attrs_define,
    field as _attrs_field,
)

T = TypeVar("T", bound="OldPublish")


@_attrs_define
class OldPublish:
    """
    Attributes:
        id (int):
        pipeline_name (str):
        pipeline_version_name (str):
    """

    id: int
    pipeline_name: str
    pipeline_version_name: str
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id

        pipeline_name = self.pipeline_name

        pipeline_version_name = self.pipeline_version_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "pipeline_name": pipeline_name,
                "pipeline_version_name": pipeline_version_name,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        pipeline_name = d.pop("pipeline_name")

        pipeline_version_name = d.pop("pipeline_version_name")

        old_publish = cls(
            id=id,
            pipeline_name=pipeline_name,
            pipeline_version_name=pipeline_version_name,
        )

        old_publish.additional_properties = d
        return old_publish

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
